Index: src/gpu/batches/GrDrawBatch.h |
diff --git a/src/gpu/batches/GrDrawBatch.h b/src/gpu/batches/GrDrawBatch.h |
index 5f37b7b0001fbc39026b3c0a9fa595340748ab7b..d1622a1cd13b2ba5aa31b421caa4982cc7d1654e 100644 |
--- a/src/gpu/batches/GrDrawBatch.h |
+++ b/src/gpu/batches/GrDrawBatch.h |
@@ -46,13 +46,18 @@ private: |
*/ |
class GrDrawBatch : public GrBatch { |
public: |
/** Method that performs an upload on behalf of a DeferredUploadFn. */ |
using WritePixelsFn = std::function<bool(GrSurface* texture, |
int left, int top, int width, int height, |
- GrPixelConfig config, const void* buffer, |
+ GrPixelConfig config, const void* buffer, |
size_t rowBytes)>; |
+ using TransferPixelsFn = std::function<bool(GrTexture* texture, |
+ int left, int top, int width, int height, |
+ GrPixelConfig config, GrBuffer* buffer, |
+ size_t offset, size_t rowBytes, |
+ GrFence* fence)>; |
/** See comments before GrDrawBatch::Target definition on how deferred uploaders work. */ |
- using DeferredUploadFn = std::function<void(WritePixelsFn&)>; |
+ using DeferredUploadFn = std::function<void(WritePixelsFn&, TransferPixelsFn&)>; |
class Target; |
@@ -46,13 +46,18 @@ private: |
class GrDrawBatch : public GrBatch { |
public: |
- /** Method that performs an upload on behalf of a DeferredUploadFn. */ |
+ /** Method that performs a texture write on behalf of a DeferredUploadFn. */ |
using WritePixelsFn = std::function<bool(GrSurface* texture, |
int left, int top, int width, int height, |